#
# spec file for package tslib
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2012 Guillaume GARDET <guillaume@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tslib
Version:        1.22
Release:        1.15
Summary:        Abstraction layer for touchscreen
License:        LGPL-2.1-or-later AND GPL-2.0-only
Group:          Hardware/Other
URL:            https://github.com/kergoth/tslib.git
Source0:        https://github.com/kergoth/tslib/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/kergoth/tslib/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  pkgconfig

%description
Tslib is an abstraction layer for touchscreen panel events.

The idea of tslib is to have a core library and a set of plugins to
manage the conversion and filtering as needed.

%package -n libts0
Summary:        Abstraction layer for touchscreens
Group:          System/Libraries

%description -n libts0
Tslib is an abstraction layer for touchscreen panel events.

The idea of tslib is to have a core library and a set of plugins to
manage the conversion and filtering as needed.

%package plugins
Summary:        Driver plugins for tslib, an abstraction layer for touchscreens
Group:          Hardware/Other

%description plugins
Tslib is an abstraction layer for touchscreen panel events.

The idea of tslib is to have a core library and a set of plugins to
manage the conversion and filtering as needed.

This subpackage contains the hardware driver plugins for tslib.

%package devel
Summary:        Development files for tslib, a touchscreen panel event layer
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}-plugins = %{version}
Requires:       glibc-devel

%description devel
Devel package for tslib. Tslib is an abstraction layer for touchscreen panel events.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install
%fdupes %{buildroot}/%{_mandir}

%post -n libts0 -p /sbin/ldconfig
%postun -n libts0 -p /sbin/ldconfig

%files devel
%dir %{_libdir}/ts
%{_includedir}/tslib.h
%{_libdir}/libts.la
%{_libdir}/pkgconfig/tslib.pc
%dir %{_libdir}/ts
%{_libdir}/ts/*.la
%{_libdir}/libts.so

%files -n libts0
%{_libdir}/libts.so.0*

%files plugins
%dir %{_libdir}/ts
%{_libdir}/ts/*.so

%files
%config %{_sysconfdir}/ts.conf
%{_bindir}/ts_calibrate
%{_bindir}/ts_conf
%{_bindir}/ts_finddev
%{_bindir}/ts_harvest
%{_bindir}/ts_print
%{_bindir}/ts_print_mt
%{_bindir}/ts_print_raw
%{_bindir}/ts_test
%{_bindir}/ts_test_mt
%{_bindir}/ts_uinput
%{_bindir}/ts_verify
%{_mandir}/*/*

%changelog
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.22:
  * fix ts_uinput build on 32 bit arch on newer kernels
  * ts_uinput: fix building on FreeBSD
  * various fixes for cmake builds
  * improved documentation for systemd
  * new filter plugin: module evthres
  * ts_calibrate: close framebuffer after validation. add timeout option -s for it
  * support for screen-rotation in ts_calibrate and linear module
  * add experimental module_raw input_evdev that needs libevdev
  * new ts_calibrate --min_interval option to avoid inaccurate calibration
  * add ts_calibrate --validate functionality to verify the calibration
  * add ts_conf_get() and ts_conf_set() API
* Thu May 24 2018 guillaume.gardet@opensuse.org
- Update to version 1.16:
  * This release includes libts version 0.9.1 and the following changes:
  - module_raw tatung is now disabled in the default build config. Users must
    ./configure --enable-tatung if they rely on it.
  - new module_raw one-wire-ts-input for FriedlyARM devices (disabled by
    default)
  - simple tslib_version() function to get the version string
  * This release includes the following bugfixes:
  - efcba6e ts_uinput: (fix for Android) write only one input_event at a time
  - e63f33f invert: fix ts_read() iteration over multiple samples
  - 932bb4f ts_uinput: fail for unsupported old kernel versions
* Mon Mar  5 2018 guillaume@opensuse.org
- Update tslib.keyring with latest key
* Wed Feb 28 2018 martink@posteo.de
- Update to version 1.15:
  * This release includes libts version 0.9.0 and the following changes:
  - New ts_get_eventpath() API to learn the opened device file path
  - ts_test_mt shows the number of supported concurrent touch contacts
  - New filter module "invert"
  - ts_uinput: fallback to fb0 and new option --nofb
  * Bugfixes
- Changes for version 1.14:
  * This release includes libts version 0.8.1 and the following changes:
  - The following modules are now disabled in the default configuration run:
    `module_raw arctic2`
    `module_raw corgi`
    `module_raw collie`
    `module_raw dmc`
    `module_raw h3600`
    `module_raw mk712`
    `module_raw ucb1x00`
    Users of those modules must enable them, like `./configure --enable-arctic2`
  - Automatic touchscreen device detection for Linux (if not defined by the user)
  - New filter plugin "lowpass"
  - SPDX license identifiers in all C source files
  * Bugfixes
* Wed Nov  8 2017 guillaume@opensuse.org
- Update to version 1.13:
  * This release includes libts version 0.8.0 and the following changes:
  - Added ts_open_restricted() and ts_close_restricted() API
  - Added TSLIB_MT_VALID bit definition for ts_sample_mt's valid flag
  - module_raw galax is now disabled in the default configuration.
    Please use module_raw input instead.
  * Bugfixes
- Changes for version 1.12:
  * This release includes libts version 0.7.2 and the following changes:
  - Generate a tracking ID value for multitouch type A devices
  - Add experimental --with-sdl2 configuration option for
    ts_calibrate and ts_test_mt
  * Bugfix
* Fri Jun 16 2017 guillaume@opensuse.org
- Fix license infos
* Mon Jun 12 2017 guillaume@opensuse.org
- Remove '%%configure' from %%prep section
* Mon Jun 12 2017 mpluskal@suse.com
- Update to version 1.11 (boo#1039249):
  * The graphical tools don't show TSLIB anymore, but Touchscreen
    instead.
  * The graphical tools support rotating the screen 90, 180 and 270
    degrees
  * man page updates
- Changes for version 1.10:
  * new ts_libversion() API and TSLIB_VERSION_MT definition
  * new module_raw dmc_dus3000 for DMC DUS Series touch screen via
    UART
  * Fixed and improved statically linked building
- Add gpg signature
- Trim unecessary dependencies
* Thu May 11 2017 guillaume@opensuse.org
- Update to tslib 1.9
- Remove upstreamed patch: use-module-raw-input-for-ts-conf.patch
- Fix library name
* Sun Mar  1 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
* Wed Mar 12 2014 guillaume@opensuse.org
- Update to 1.1:
  - support for running in a different resolution than during calibration
  - basic multi-touch support (incomplete implementation of the multi-touch protocol)
  - 4 new tslib plugins (dmc, touchkit, egalax, palm pre)
* Wed Nov 13 2013 jengelh@inai.de
- Fix insufficient description for libts-1_0-0
- Set RPM groups; simpler make install line; remove redundant
  %%clean section
- Own all created directories
* Mon Aug 12 2013 guillaume@opensuse.org
- Add baselibs.conf (needed to use tslib with directfb)
* Mon Aug 12 2013 guillaume@opensuse.org
- Update to git e2e03ef719
* Thu Jan  3 2013 cfarrell@suse.com
- license update: LGPL-2.0+ and GPL-2.0+
  Library itself is LGPL (2.0) and there are some GPL-2.0+ files in the
  test subdir
* Wed Jan  2 2013 sleep_walker@suse.cz
- follow policy for shared libraries and separate library package
- separate plugins
- instead of duplicate file create symlink
* Tue Dec 25 2012 sleep_walker@suse.cz
- devel package now requires tslib itself
  as libts.so is in tslib package, it is double-weird not to be
  there
* Tue Dec 25 2012 sleep_walker@suse.cz
- fix for non SUSE distros
* Thu Nov  8 2012 guillaume@opensuse.org
- Initial release (git f6c499a523)
